Note

This section is incomplete and will soon be updated.

The AEAs currently use the addresses associated with their private-public key pairs to identify themselves. To learn how to generate a private-public key pair check out this section. To learn more about public-key cryptography check out Wikipedia. AEAs can provide attestations of their identity using third-party solutions. We have implemented a demo using Aries Hyperledger Cloud Agent which is available here.